bison-patches
[Top][All Lists]
Advanced

[Date Prev][Date Next][Thread Prev][Thread Next][Date Index][Thread Index]

minor improvements to comments


From: Joel E. Denny
Subject: minor improvements to comments
Date: Mon, 9 Jul 2007 22:58:37 -0400 (EDT)

Committed.

Index: ChangeLog
===================================================================
RCS file: /sources/bison/bison/ChangeLog,v
retrieving revision 1.1708
diff -p -u -r1.1708 ChangeLog
--- ChangeLog   3 Jul 2007 14:08:29 -0000       1.1708
+++ ChangeLog   10 Jul 2007 02:53:46 -0000
@@ -1,3 +1,11 @@
+2007-07-09  Joel E. Denny  <address@hidden>
+
+       * LR0.c (new_itemsets): Fix wording in comments: say item index rather
+       than item number.
+       * closure.c (closure): Likewise.
+       * state.h (reductions): Comment sorting of rules.
+       (state): Comment sorting of items.
+
 2007-07-02  Joel E. Denny  <address@hidden>
 
        Fix C++ test cases after recent Gnulib changes.  Discussed starting at
Index: src/LR0.c
===================================================================
RCS file: /sources/bison/bison/src/LR0.c,v
retrieving revision 1.99
diff -p -u -r1.99 LR0.c
--- src/LR0.c   29 May 2007 04:24:17 -0000      1.99
+++ src/LR0.c   10 Jul 2007 02:53:46 -0000
@@ -170,9 +170,9 @@ free_storage (void)
 | points to a vector of item numbers activated if that symbol is |
 | shifted, and kernel_size[symbol] is their numbers.             |
 |                                                                |
-| itemset is sorted on item number from ritem, which is sorted   |
-| on rule number.  Compute each kernel_base[symbol] with the     |
-| same sort.                                                     |
+| itemset is sorted on item index in ritem, which is sorted on   |
+| rule number.  Compute each kernel_base[symbol] with the same   |
+| sort.                                                          |
 `---------------------------------------------------------------*/
 
 static void
Index: src/closure.c
===================================================================
RCS file: /sources/bison/bison/src/closure.c,v
retrieving revision 1.77
diff -p -u -r1.77 closure.c
--- src/closure.c       29 May 2007 04:24:17 -0000      1.77
+++ src/closure.c       10 Jul 2007 02:53:46 -0000
@@ -213,7 +213,7 @@ closure (item_number *core, size_t n)
     if (ISVAR (ritem[core[c]]))
       bitset_or (ruleset, ruleset, FDERIVES (ritem[core[c]]));
 
-  /* core is sorted on item number from ritem, which is sorted on rule number.
+  /* core is sorted on item index in ritem, which is sorted on rule number.
      Compute itemset with the same sort.  */
   nitemset = 0;
   c = 0;
Index: src/state.h
===================================================================
RCS file: /sources/bison/bison/src/state.h,v
retrieving revision 1.55
diff -p -u -r1.55 state.h
--- src/state.h 28 May 2007 04:14:18 -0000      1.55
+++ src/state.h 10 Jul 2007 02:53:47 -0000
@@ -185,6 +185,7 @@ typedef struct
 {
   int num;
   bitset *lookahead_tokens;
+  /* Sorted ascendingly on rule number.  */
   rule *rules[1];
 } reductions;
 
@@ -210,8 +211,8 @@ struct state
      a human readable description of the resolution.  */
   const char *solved_conflicts;
 
-  /* Its items.  Must be last, since ITEMS can be arbitrarily large.
-     */
+  /* Its items.  Must be last, since ITEMS can be arbitrarily large.  Sorted
+     ascendingly on item index in RITEM, which is sorted on rule number.  */
   size_t nitems;
   item_number items[1];
 };




reply via email to

[Prev in Thread] Current Thread [Next in Thread]